############
pytest-REANA
############

.. image:: https://img.shields.io/pypi/pyversions/pytest-reana.svg
      :target: https://pypi.org/pypi/pytest-reana

.. image:: https://github.com/reanahub/pytest-reana/workflows/CI/badge.svg
      :target: https://github.com/reanahub/pytest-reana/actions

.. image:: https://readthedocs.org/projects/pytest-reana/badge/?version=latest
      :target: https://pytest-reana.readthedocs.io/en/latest/?badge=latest

.. image:: https://codecov.io/gh/reanahub/pytest-reana/branch/master/graph/badge.svg
      :target: https://codecov.io/gh/reanahub/pytest-reana

.. image:: https://badges.gitter.im/Join%20Chat.svg
      :target: https://gitter.im/reanahub/reana?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

.. image:: https://img.shields.io/github/license/reanahub/pytest-reana.svg
      :target: https://github.com/reanahub/pytest-reana/blob/master/LICENSE

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
      :target: https://github.com/psf/black

About
=====

pytest-REANA is a component of the `REANA <http://www.reana.io/>`_ reusable and
reproducible research data analysis platform. It provides pytest fixtures and
test utilities.

Features
========

- pytest fixtures
- mocking OpenAPI client with request format validation
- mocking Advanced Message Queuing Protocol consumers and producers
- mocking Celery tasks
- mocking file system workspace access
- mocking database access
- includes sample workspace directory

Usage
=====

The detailed information on how to install and use REANA can be found in
`docs.reana.io <https://docs.reana.io>`_.

Useful links
============

- `REANA project home page <http://www.reana.io/>`_
- `REANA user documentation <https://docs.reana.io>`_
- `REANA user support forum <https://forum.reana.io>`_

- `pytest-REANA releases <https://pytest-reana.readthedocs.io/en/latest#changes>`_
- `pytest-REANA developer documentation <https://pytest-reana.readthedocs.io/>`_
- `pytest-REANA known issues <https://github.com/reanahub/pytest-reana/issues>`_
- `pytest-REANA source code <https://github.com/reanahub/pytest-reana>`_
